@@ -18,11 +18,11 @@ class SetStaticFieldHandler < AbstractCommandHandler
       merged_value = '@@' + command.payload[1]
       begin
         command.payload[0].class_variable_set(merged_value, command.payload[2])
-      rescue NameError
+      rescue Exception
         fields = command.payload[0].class_variables
         message = "Field #{command.payload[1]} not found in class #{command.payload[0].name}. Available fields:\n"
         fields.each { |field_iter| message += "#{field_iter}\n" }
-        raise Exception, message
+        raise ArgumentError, message
       end
     rescue Exception => e
       return e
